@@ -17,7 +17,11 @@ get_unique_values <- function(
   # Extract unique values for the mode column
   if (length(mode_column) == 0) {
     unique_modes <- list()
-  } else {
+  } 
+  # else if (mode_column == ATTR_NAMES$CONTEXT_ID) {
+  #   unique_modes <- ATTR_NAMES$CONTEXT_ID;
+  # }
+  else {
     unique_modes <- sort(unique(df[[mode_column]]))
   }
   
@@ -137,8 +141,6 @@ windows_weights <- function(...) {
   do.call(context_tensor, list(...))
 }
 
-
-
 # If sender_cols, receiver_cols, or mode_column are empty, have our standin. Be sure to fill in 
 # standin as expected in multidim_arr. 
 # We do this so we don't fail when they don't specify senders/receivers/mode
